---
title: کدهای کوتاه
weight: 9
prev: /docs/guide/diagrams
next: /docs/guide/shortcodes/filetree
---

[کدهای کوتاه Hugo](https://gohugo.io/content-management/shortcodes/) قطعه‌های ساده‌ای در داخل پرونده‌های محتوای شما هستند که قالب‌های داخلی یا سفارشی را فراخوانی می‌کنند.

هگزترا مجموعه‌ای از کدهای کوتاه زیبا را برای بهبود محتوای شما ارائه می‌کند.


{{< cards >}}
  {{< card link="filetree" title="FileTree" icon="folder-tree" >}}
  {{< card link="icon" title="آیکون" icon="badge-check" >}}
  {{< card link="details" title="جزئیات" icon="chevron-right" >}}
  {{< card link="tabs" title="زبانه‌ها" icon="collection" >}}
  {{< card link="callout" title="فراخوانی" icon="warning" >}}
  {{< card link="cards" title="کارت‌ها" icon="card" >}}
  {{< card link="steps" title="مراحل" icon="one" >}}
{{< /cards >}}
